# EasySim

## Prerequisites

This code is tested with Python 3.8 on Linux.

## Installation

For good practice for Python package management, it is recommended to install the package into a virtual environment (e.g., `virtualenv` or `conda`).

First clone the repo and install with `pip`'s editable mode.

```Shell
git clone git@github.com:NVlabs/easysim.git
cd easysim
pip install -e .[dev]
```
